SubscribeRsp

Struct SubscribeRsp 

pub struct SubscribeRsp { /* private fields */ }
Response to the subscription request, representing the Suback packet.

In order to receive messages published on the subscribed topics use the stream method.

Implementations

Source

impl SubscribeRsp

pub fn stream(self) -> SubscribeStream

Transforms this response into the asynchronous stream of messages published to the subscribed topics.

pub fn reason_string(&self) -> Option<&str>

Accesses reason string property.

pub fn user_properties(&self) -> &UserProperties

Accesses user properties.

pub fn payload(&self) -> &[SubackReason]

Accesses the payload being a list of SubackReason codes. Each reason code represents the result of the subscribe operation for the given topic.