pub struct SubscribeRsp { /* private fields */ }Expand description
Response to the subscription request, representing the Suback packet.
In order to receive messages published on the subscribed topics use the stream method.
Implementations
Sourceimpl SubscribeRsp
impl SubscribeRsp
Sourcepub fn stream(self) -> SubscribeStream
pub fn stream(self) -> SubscribeStream
Transforms this response into the asynchronous stream of messages published to the subscribed topics.
Sourcepub fn reason_string(&self) -> Option<&str>
pub fn reason_string(&self) -> Option<&str>
Accesses reason string property.
Sourcepub fn user_properties(&self) -> &UserProperties
pub fn user_properties(&self) -> &UserProperties
Accesses user properties.
Sourcepub fn payload(&self) -> &[SubackReason]
pub fn payload(&self) -> &[SubackReason]
Accesses the payload being a list of SubackReason codes. Each reason code represents the result of the subscribe operation for the given topic.